@@ -1,4 +1,6 @@
-"""Top-level package for pyx2pxd."""
+"""
+.. include:: ../../README.md
+"""
 
 __author__ = """Bruno Manuel Santos Saraiva"""
 __email__ = 'bruno.msaraiva2@gmail.com'
